diff --git a/acdx/lib/libacdx.h b/acdx/lib/libacdx.h
index a00424c1b8291dbccd1001877f0d864fab946e22..7c96456c657b934d23ce8e6877c52c94e5580c5e 100644
--- a/acdx/lib/libacdx.h
+++ b/acdx/lib/libacdx.h
@@ -9,8 +9,10 @@ typedef enum {
  } AcdxLibCompletion;
 
 
-AcdxLibCompletion AcdxLoadFunction(unsigned int freq,         /* Frequency in Hertz */
-				   unsigned int ampl);        /* Amplitude in Milli-Volts */
+AcdxLibCompletion AcdxLoadFunction(
+                  unsigned int freq,         /* Frequency in Hertz */
+                  unsigned int ampl,       /* Amplitude in Milli-Volts */
+                  unsigned int ftop);       /* Flat-Top Width in Milli-Seconds */
 
 AcdxLibCompletion AcdxArm();      /* Arm */
 
diff --git a/acdx/lib/libamp.c b/acdx/lib/libamp.c
index e47e72eea1ce4412756855b7e1c8bf731ffcb019..8b4f54c7c8b6098c18d87e050b2529a05c2bac49 100644
--- a/acdx/lib/libamp.c
+++ b/acdx/lib/libamp.c
@@ -331,7 +331,7 @@ char *cp;
    cp = GetRouteName(GetFile("AmpDevice"));
    if ((cp == NULL) || (*cp == '.')) cp = DEFAULT_AMP_DEVICE;
 
-   fprintf(stderr,"libamp:Opening:AmpDevice:%s",cp);
+   fprintf(stderr,"libamp:Opening:AmpDevice:%s\n",cp);
 
    if ((amp = open(cp,O_RDWR|O_SYNC|O_NDELAY,0)) > 0) {
       if (SetOptions(19200,8,"None","1",0,0) > 0) return amp;
@@ -352,7 +352,7 @@ char *cp;
 
    tcflush(amp, TCIOFLUSH);
    if (close(amp) != 0) {
-      fprintf(stderr,"libamp:Error:Closing:AmpDevice:%s",cp);
+      fprintf(stderr,"libamp:Error:Closing:AmpDevice:%s\n",cp);
       perror("close");
    }
    AmpOpen();
@@ -630,7 +630,7 @@ char param[6];
 
 // ====================================================
 
-static int CompareParamsFile(int blk) {
+static int CompareParamsFile(int blk, int ampId) {
 
 FILE *fp;
 int i, len, cc, bad;
@@ -644,6 +644,7 @@ char *cp;
 
    cp = GetFile("RefAmpDspBin");
    sprintf(path,"%s%d",path,blk);
+   sprintf(path,"%s_%d",path,ampId);
 
    umask(0);
    fp = fopen(path,"r");
@@ -697,7 +698,7 @@ int ReadStatBlk() {
 
 // ====================================================
 
-int CompareStatusFile() {
+int CompareStatusFile(int ampId) {
 
 FILE *fp;
 int cc;
@@ -706,6 +707,9 @@ char *cp;
 AmpStatus *ref;
 
    cp = GetFile("RefAmpStatus");
+
+   sprintf(path,"%s_%d",path,ampId);
+
    umask(0);
    fp = fopen(path,"r");
    if (fp == NULL) {
@@ -863,10 +867,10 @@ int i, blk, bad;
       sprintf(Id,"%02X",i);
       for (blk=0; blk<3; blk++) {
 	 if (GetDspParams(blk) == 0) bad++;
-	 if (CompareParamsFile(blk) == 0) bad++;
+	 if (CompareParamsFile(blk, i) == 0) bad++;
       }
       if (ReadStatBlk() == 0) bad++;
-      if (CompareStatusFile() == 0) bad++;
+      if (CompareStatusFile(i) == 0) bad++;
    }
    AmpUnBlock();
diff --git a/acdx/lib/libacdx.c b/acdx/lib/libacdx.c
index c4a2c18cb81deec5a7c7a61136b5d1cb89467615..3dbcff47efbe24fd9008cdd6eaa7ffa83f8c5e57 100644
--- a/acdx/lib/libacdx.c
+++ b/acdx/lib/libacdx.c
@@ -184,8 +184,10 @@ AcdxLibCompletion AcdxLibInit() {
 
 /* ================================================ */
 
-AcdxLibCompletion AcdxLoadFunction(unsigned int f,   /* Frequency in Hertz */
-				   unsigned int a) { /* Amplitude in Milli-Volts */
+AcdxLibCompletion AcdxLoadFunction(
+					unsigned int f,      /* Frequency in Hertz */
+					unsigned int a,     /* Amplitude in Milli-Volts */
+					unsigned int ft) {  /* ftop in Milli-Seconds */
 
    if (AcdxLibInit() == AcdxLibOK) {
 
@@ -193,6 +195,8 @@ AcdxLibCompletion AcdxLoadFunction(unsigned int f,   /* Frequency in Hertz */
       else   freq = 3000;
       if (a) ampl = a;
       else   ampl = 500;
+      if (ft) ftop = ft * 1000; // ft in ms
+      else   ftop = 200000;
 
       SinWave();
       if (PutFunc()) return AcdxLibOK;